;; Generated package description from rcirc-menu.el  -*- no-byte-compile: t -*-
(define-package "rcirc-menu" "1.1.0.20201201.215557" "A menu of all your rcirc connections" 'nil :url "https://elpa.gnu.org/packages/rcirc-menu.html" :keywords '("comm") :authors '(("Alex Schroeder" . "alex@gnu.org")) :maintainer '("Alex Schroeder" . "alex@gnu.org"))
